<?php

namespace Kolab\FreeBusy;

use Monolog\Logger as Monologger;
use Monolog\Handler\StreamHandler;
use Monolog\Handler\SyslogHandler;
use Monolog\Handler\NullHandler;

/**
 * Helper class for creating up Monolog instanced with local configration
 */
class Logger
{
	private static $instances = array();

	/**
	 * Static getter for a Monolog\Logger instance
	 */
	public static function get($name, $level = 0)
	{
		if (!isset(self::$instances[$name]) || ($level && !self::$instances[$name]->isHandling($level))) {
			$logger = new Monologger($name);

			// read log config
			$config = Config::getInstance();
			$identity = $config->get('log.name', 'freebusy');
			$loglevel = $level ?: $config->get('log.level', Monologger::INFO);

			switch ($config->get('log.driver')) {
				case 'file':
					$logdir = Utils::abspath($config->get('log.path'), '/');
					$logger->pushHandler(new StreamHandler($logdir . $identity . '.log', $loglevel));
					break;

				case 'syslog':
					$logger->pushHahdler(new SyslogHandler($identity, $config->get('log.facility', 'user'), $loglevel));
					break;

				default:
					// null handler if logging is disabled
					$logger->pushHandler(new NullHandler);
			}

			self::$instances[$name] = $logger;
		}
		
		return self::$instances[$name];
	}

}

