<?php

namespace Kolab\FreeBusy;

/**
 * Implementation of a Free/Busy data source reading from remote URLs through HTTP
 */
class SourceURL extends Source
{
	/**
	 * @see Source::getFreeBusyData()
	 */
	public function getFreeBusyData($user, $extended)
	{
		$config = $this->getUserConfig($user);

		// prepare HTTP stream context
		$context = stream_context_create(array(
			'http' => array(
				'user_agent' => "Kolab Free-Busy Service/0.1.0",
				'timeout'    => 10,
			),
		));

		// set HTTP auth credentials
		if (!empty($config['user'])) {
			stream_context_set_option($context, array(
				'http' => array(
					'header'  => "Authorization: Basic " . base64_encode($config['user'] . ':' . $config['pass']) . "\r\n",
				),
			));
			$config['url'] = self::composeUrl($config);  // re-compose url without user:pass
		}

		$data = file_get_contents($config['url'], false, $context);

		// log this...
		Logger::get('url')->addInfo("Fetching data from " . $config['url'] . ": " . ($data ? 'OK' : 'FAILED'));

		return $data;
	}

	/**
	 * Compose a full url from the given config (previously extracted with parse_url())
	 */
	private static function composeUrl($config)
	{
		$scheme = isset($config['scheme']) ?       $config['scheme'] . '://' : ''; 
		$host   = isset($config['host'])   ?       $config['host']  : ''; 
		$port   = isset($config['port'])   ? ':' . $config['port']  : ''; 
		$path   = isset($config['path'])   ?       $config['path']  : ''; 
		$query  = isset($config['query'])  ? '?' . $config['query'] : ''; 
		return $scheme . $host . $port . $path . $query;
	}
}
